==> ZenTaoALM.11.6.2.int.zip: zentaoalm/module/dev/lang/en.php <==
<?php
$lang->dev->common     = 'Develop';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Database';
$lang->dev->editor     = 'Editor';
$lang->dev->dbList     = 'Database';
$lang->dev->moduleList = 'Modules';
$lang->dev->params     = 'Parameters';
$lang->dev->type       = 'Type';
$lang->dev->desc       = 'Description';
$lang->dev->noParams   = 'No Parameters';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange  = 'Parameter Range: %s';
$lang->dev->paramDate   = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor  = 'Color format: #RGB, e.g. #3da7f5';
$lang->dev->paramMailto = "User account. Separate accounts by ','.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feild';
$lang->dev->fields['desc']   = 'Description';
$lang->dev->fields['type']   = 'Type';
$lang->dev->fields['length'] = 'Length';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Action';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Build';
$lang->dev->tableList['burn']             = 'Burndown Chart';
$lang->dev->tableList['case']             = 'Test Case';
$lang->dev->tableList['casestep']         = 'Case Step';
$lang->dev->tableList['company']          = 'Company';
$lang->dev->tableList['config']           = 'Configuration';
$lang->dev->tableList['custom']           = 'Custom';
$lang->dev->tableList['dept']             = 'Department';
$lang->dev->tableList['doc']              = 'Document';
$lang->dev->tableList['doclib']           = 'Document Library';
$lang->dev->tableList['effort']           = 'Effort';
$lang->dev->tableList['extension']        = 'Extension';
$lang->dev->tableList['file']             = 'File';
$lang->dev->tableList['group']            = 'Group';
$lang->dev->tableList['grouppriv']        = 'Privilege';
$lang->dev->tableList['history']          = 'History';
$lang->dev->tableList['lang']             = 'Language';
$lang->dev->tableList['module']           = 'Module';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . 'Plan';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . 'Story';
$lang->dev->tableList['release']          = 'Release';
$lang->dev->tableList['story']            = 'Story';
$lang->dev->tableList['storyspec']        = 'Story Description';
$lang->dev->tableList['task']             = 'Task';
$lang->dev->tableList['taskestimate']     = 'Estimates';
$lang->dev->tableList['team']             = 'Team';
$lang->dev->tableList['testresult']       = 'Test Result';
$lang->dev->tableList['testrun']          = 'Test Run';
$lang->dev->tableList['testtask']         = 'Test Request';
$lang->dev->tableList['todo']             = 'Todo';
$lang->dev->tableList['user']             = 'User';
$lang->dev->tableList['usercontact']      = 'User Contact';
$lang->dev->tableList['usergroup']        = 'User Group';
$lang->dev->tableList['userquery']        = 'User Query';
$lang->dev->tableList['usertpl']          = 'User Template';
$lang->dev->tableList['admin']            = 'Admin';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Backup';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Convert';
$lang->dev->tableList['dev']              = 'Develop';
$lang->dev->tableList['editor']           = 'Editor';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Home';
$lang->dev->tableList['install']          = 'Install';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Misc.';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'QA';
$lang->dev->tableList['report']           = 'Report';
$lang->dev->tableList['search']           = 'Search';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'Test Case';
$lang->dev->tableList['testreport']       = 'Test Report';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['tree']             = 'Module Tree';
$lang->dev->tableList['upgrade']          = 'Update';
$lang->dev->tableList['cron']             = 'Cron';
$lang->dev->tableList['datatable']        = 'Data Table';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Branch';
$lang->dev->tableList['doccontent']       = 'Doc Content';
$lang->dev->tableList['storystage']       = 'Story Phase';
$lang->dev->tableList['translate']        = 'Translate';
$lang->dev->tableList['tutorial']         = 'Tutorial';
$lang->dev->tableList['suitecase']        = 'Suite Case';
$lang->dev->tableList['score']            = 'Score';
$lang->dev->tableList['entry']            = 'Application';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Log';
$lang->dev->tableList['message']          = 'Message';
$lang->dev->tableList['notify']           = 'Notification';
$lang->dev->tableList['userview']         = 'User Privilege';
$lang->dev->tableList['im_chatuser']      = 'Client Users';
$lang->dev->tableList['im_message']       = 'Client Messages';
$lang->dev->tableList['translation']      = 'Translation';
$lang->dev->tableList['im_messagestatus'] = 'Client Messages Status';

$lang->dev->groupList['my']      = 'Dashboard';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = 'QA';
$lang->dev->groupList['doc']     = 'Doc';
$lang->dev->groupList['report']  = 'Report';
$lang->dev->groupList['company'] = 'Company';
$lang->dev->groupList['repo']    = 'Code';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = 'Message';

$lang->dev->endGroupList['admin']  = 'Admin';
$lang->dev->endGroupList['system'] = 'System';
$lang->dev->endGroupList['other']  = 'Others';

==> ZenTaoALM.12.4.3.int.zip: zentaoalm/module/dev/lang/en.php <==
<?php
$lang->dev->common     = 'Develop';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Database';
$lang->dev->editor     = 'Editor';
$lang->dev->translate  = 'Translate';
$lang->dev->dbList     = 'Database';
$lang->dev->moduleList = 'Modules';
$lang->dev->params     = 'Parameters';
$lang->dev->type       = 'Type';
$lang->dev->desc       = 'Description';
$lang->dev->noParams   = 'No Parameters';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange    = 'Parameter Range: %s';
$lang->dev->paramDate     = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor    = 'Color format: #RGB, e.g. #3da7f5';
$lang->dev->paramMailto   = "User account. Separate accounts by ','.";
$lang->dev->noteEditor    = "The editor is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of the <a href='https://www.zentao.pm/extension-viewExt-150.html' target='_blank'>editor</a>.";
$lang->dev->noteTranslate = "The translation is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of <a href='https://www.zentao.pm/extension-viewExt-151.html' target='_blank'>translation</a>.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feild';
$lang->dev->fields['desc']   = 'Description';
$lang->dev->fields['type']   = 'Type';
$lang->dev->fields['length'] = 'Length';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Action';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Build';
$lang->dev->tableList['burn']             = 'Burndown Chart';
$lang->dev->tableList['case']             = 'Test Case';
$lang->dev->tableList['casestep']         = 'Case Step';
$lang->dev->tableList['company']          = 'Company';
$lang->dev->tableList['config']           = 'Configuration';
$lang->dev->tableList['custom']           = 'Custom';
$lang->dev->tableList['dept']             = 'Department';
$lang->dev->tableList['doc']              = 'Document';
$lang->dev->tableList['doclib']           = 'Document Library';
$lang->dev->tableList['effort']           = 'Effort';
$lang->dev->tableList['extension']        = 'Extension';
$lang->dev->tableList['file']             = 'File';
$lang->dev->tableList['group']            = 'Group';
$lang->dev->tableList['grouppriv']        = 'Privilege';
$lang->dev->tableList['history']          = 'History';
$lang->dev->tableList['lang']             = 'Language';
$lang->dev->tableList['module']           = 'Module';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . 'Plan';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . 'Story';
$lang->dev->tableList['release']          = 'Release';
$lang->dev->tableList['story']            = 'Story';
$lang->dev->tableList['storyspec']        = 'Story Description';
$lang->dev->tableList['task']             = 'Task';
$lang->dev->tableList['taskestimate']     = 'Estimates';
$lang->dev->tableList['team']             = 'Team';
$lang->dev->tableList['testresult']       = 'Test Result';
$lang->dev->tableList['testrun']          = 'Test Run';
$lang->dev->tableList['testtask']         = 'Test Request';
$lang->dev->tableList['todo']             = 'Todo';
$lang->dev->tableList['user']             = 'User';
$lang->dev->tableList['usercontact']      = 'User Contact';
$lang->dev->tableList['usergroup']        = 'User Group';
$lang->dev->tableList['userquery']        = 'User Query';
$lang->dev->tableList['usertpl']          = 'User Template';
$lang->dev->tableList['admin']            = 'Admin';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Backup';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Convert';
$lang->dev->tableList['dev']              = 'Develop';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Home';
$lang->dev->tableList['install']          = 'Install';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Misc.';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'Test';
$lang->dev->tableList['report']           = 'Report';
$lang->dev->tableList['search']           = 'Search';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'Test Case';
$lang->dev->tableList['testreport']       = 'Test Report';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['caselib']          = 'Case Library';
$lang->dev->tableList['tree']             = 'Module Tree';
$lang->dev->tableList['upgrade']          = 'Update';
$lang->dev->tableList['cron']             = 'Cron';
$lang->dev->tableList['datatable']        = 'Data Table';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Branch';
$lang->dev->tableList['doccontent']       = 'Doc Content';
$lang->dev->tableList['storystage']       = 'Story Phase';
$lang->dev->tableList['tutorial']         = 'Tutorial';
$lang->dev->tableList['suitecase']        = 'Suite Case';
$lang->dev->tableList['score']            = 'Score';
$lang->dev->tableList['entry']            = 'Application';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Log';
$lang->dev->tableList['message']          = 'Message';
$lang->dev->tableList['notify']           = 'Notification';
$lang->dev->tableList['userview']         = 'User Privilege';
$lang->dev->tableList['repo']             = 'Code';
$lang->dev->tableList['repohistory']      = 'Repo History';
$lang->dev->tableList['repofiles']        = 'Repo Files';
$lang->dev->tableList['repobranch']       = 'Repo Branch';
$lang->dev->tableList['ci']               = 'CI';
$lang->dev->tableList['compile']          = 'Compile';
$lang->dev->tableList['jenkins']          = 'Jenkins';
$lang->dev->tableList['job']              = 'Job';

$lang->dev->groupList['my']      = 'Dashboard';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = 'Test';
$lang->dev->groupList['doc']     = 'Doc';
$lang->dev->groupList['report']  = 'Report';
$lang->dev->groupList['company'] = 'Company';
$lang->dev->groupList['repo']    = 'CI';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = 'Message';

$lang->dev->endGroupList['admin']  = 'Admin';
$lang->dev->endGroupList['system'] = 'System';
$lang->dev->endGroupList['other']  = 'Others';
